==> haskell-attoparsec-0.14.4-120-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-attoparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-attoparsec-z-attoparsec-internal
version:              0.14.4
package-name:         attoparsec
lib-name:             attoparsec-internal
id:
    attoparsec-0.14.4-Ce7Q2MMNX9p2Ul2Gbzzqux-attoparsec-internal

key:
    attoparsec-0.14.4-Ce7Q2MMNX9p2Ul2Gbzzqux-attoparsec-internal

license:              BSD-3-Clause
maintainer:
    Bryan O'\''Sullivan <bos@serpentine.com>, Ben Gamari <ben@smart-cactus.org>

author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             https://github.com/bgamari/attoparsec
synopsis:             Fast combinator parsing for bytestrings and text
description:
    A fast parser combinator library, aimed particularly at dealing
    efficiently with network protocols and complicated text/binary
    file formats.

category:             Text, Parsing
abi:                  875e40f8c3b5eba96056a23f393f98fe
exposed-modules:
    Data.Attoparsec.ByteString.Buffer
    Data.Attoparsec.ByteString.FastSet Data.Attoparsec.Internal.Compat
    Data.Attoparsec.Internal.Fhthagn Data.Attoparsec.Text.Buffer
    Data.Attoparsec.Text.FastSet

import-dirs:          /usr/lib/ghc-9.4.8/site-local/attoparsec-0.14.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/attoparsec-0.14.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/attoparsec-0.14.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-attoparsec
hs-libraries:
    HSattoparsec-0.14.4-Ce7Q2MMNX9p2Ul2Gbzzqux-attoparsec-internal

depends:
    array-0.5.4.0 base-4.17.2.1 bytestring-0.11.5.3 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-attoparsec/html/attoparsec.haddock
haddock-html:         /usr/share/doc/haskell-attoparsec/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 attoparsec
version:              0.14.4
visibility:           public
id:                   attoparsec-0.14.4-FDtC6GeLACtJHW3icA3qMM
key:                  attoparsec-0.14.4-FDtC6GeLACtJHW3icA3qMM
license:              BSD-3-Clause
maintainer:
    Bryan O'\''Sullivan <bos@serpentine.com>, Ben Gamari <ben@smart-cactus.org>

author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             https://github.com/bgamari/attoparsec
synopsis:             Fast combinator parsing for bytestrings and text
description:
    A fast parser combinator library, aimed particularly at dealing
    efficiently with network protocols and complicated text/binary
    file formats.

category:             Text, Parsing
abi:                  2c75ace5a938f7b74a0f1670dbd8a144
exposed:              True
exposed-modules:
    Data.Attoparsec Data.Attoparsec.ByteString
    Data.Attoparsec.ByteString.Char8 Data.Attoparsec.ByteString.Lazy
    Data.Attoparsec.Char8 Data.Attoparsec.Combinator
    Data.Attoparsec.Internal Data.Attoparsec.Internal.Types
    Data.Attoparsec.Lazy Data.Attoparsec.Number Data.Attoparsec.Text
    Data.Attoparsec.Text.Lazy Data.Attoparsec.Types
    Data.Attoparsec.Zepto

hidden-modules:
    Data.Attoparsec.ByteString.Internal Data.Attoparsec.Text.Internal

import-dirs:          /usr/lib/ghc-9.4.8/site-local/attoparsec-0.14.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/attoparsec-0.14.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/attoparsec-0.14.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-attoparsec
hs-libraries:         HSattoparsec-0.14.4-FDtC6GeLACtJHW3icA3qMM
depends:
    array-0.5.4.0
    attoparsec-0.14.4-Ce7Q2MMNX9p2Ul2Gbzzqux-attoparsec-internal
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.0
    ghc-prim-0.9.1 scientific-0.3.7.0-Kb5Gqy0LO2R6GqxRC9SGn9 text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-attoparsec/html/attoparsec.haddock
haddock-html:         /usr/share/doc/haskell-attoparsec/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-attoparsec-0.14.4-121-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-attoparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-attoparsec-z-attoparsec-internal
version:              0.14.4
package-name:         attoparsec
lib-name:             attoparsec-internal
id:
    attoparsec-0.14.4-53rDT7hOS3eFo3KKVNDK0W-attoparsec-internal

key:
    attoparsec-0.14.4-53rDT7hOS3eFo3KKVNDK0W-attoparsec-internal

license:              BSD-3-Clause
maintainer:
    Bryan O'\''Sullivan <bos@serpentine.com>, Ben Gamari <ben@smart-cactus.org>

author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             https://github.com/bgamari/attoparsec
synopsis:             Fast combinator parsing for bytestrings and text
description:
    A fast parser combinator library, aimed particularly at dealing
    efficiently with network protocols and complicated text/binary
    file formats.

category:             Text, Parsing
abi:                  8d9f71b0d4a7eda5108b3bf094c6b240
exposed-modules:
    Data.Attoparsec.ByteString.Buffer
    Data.Attoparsec.ByteString.FastSet Data.Attoparsec.Internal.Compat
    Data.Attoparsec.Internal.Fhthagn Data.Attoparsec.Text.Buffer
    Data.Attoparsec.Text.FastSet

import-dirs:          /usr/lib/ghc-9.4.8/site-local/attoparsec-0.14.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/attoparsec-0.14.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/attoparsec-0.14.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-attoparsec
hs-libraries:
    HSattoparsec-0.14.4-53rDT7hOS3eFo3KKVNDK0W-attoparsec-internal

depends:
    array-0.5.4.0 base-4.17.2.1 bytestring-0.11.5.3 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-attoparsec/html/attoparsec.haddock
haddock-html:         /usr/share/doc/haskell-attoparsec/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 attoparsec
version:              0.14.4
visibility:           public
id:                   attoparsec-0.14.4-Ie40PJLLZWYz4b9BsvrTL
key:                  attoparsec-0.14.4-Ie40PJLLZWYz4b9BsvrTL
license:              BSD-3-Clause
maintainer:
    Bryan O'\''Sullivan <bos@serpentine.com>, Ben Gamari <ben@smart-cactus.org>

author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             https://github.com/bgamari/attoparsec
synopsis:             Fast combinator parsing for bytestrings and text
description:
    A fast parser combinator library, aimed particularly at dealing
    efficiently with network protocols and complicated text/binary
    file formats.

category:             Text, Parsing
abi:                  3224cd5798b29d7aa18f0963c307e0fb
exposed:              True
exposed-modules:
    Data.Attoparsec Data.Attoparsec.ByteString
    Data.Attoparsec.ByteString.Char8 Data.Attoparsec.ByteString.Lazy
    Data.Attoparsec.Char8 Data.Attoparsec.Combinator
    Data.Attoparsec.Internal Data.Attoparsec.Internal.Types
    Data.Attoparsec.Lazy Data.Attoparsec.Number Data.Attoparsec.Text
    Data.Attoparsec.Text.Lazy Data.Attoparsec.Types
    Data.Attoparsec.Zepto

hidden-modules:
    Data.Attoparsec.ByteString.Internal Data.Attoparsec.Text.Internal

import-dirs:          /usr/lib/ghc-9.4.8/site-local/attoparsec-0.14.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/attoparsec-0.14.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/attoparsec-0.14.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-attoparsec
hs-libraries:         HSattoparsec-0.14.4-Ie40PJLLZWYz4b9BsvrTL
depends:
    array-0.5.4.0
    attoparsec-0.14.4-53rDT7hOS3eFo3KKVNDK0W-attoparsec-internal
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.0
    ghc-prim-0.9.1 scientific-0.3.7.0-IuEDgnpy5lN4JI5naZeXd4 text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-attoparsec/html/attoparsec.haddock
haddock-html:         /usr/share/doc/haskell-attoparsec/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
